@@ -1,7 +1,7 @@
 #!/bin/sh
 set -e
 set -x
-aclocal -I .
+aclocal -I config
 autoheader
 libtoolize --force --automake --copy
 automake --gnu --include-deps --copy --add-missing
