@@ -276,6 +276,7 @@ struct hostrange_cmd_args
 #define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE      0x00000100
 #define IPMI_TOOL_WORKAROUND_FLAGS_IGNORE_SOL_PAYLOAD_SIZE     0x00000200
 #define IPMI_TOOL_WORKAROUND_FLAGS_IGNORE_SOL_PORT             0x00000400
+#define IPMI_TOOL_WORKAROUND_FLAGS_SKIP_SOL_ACTIVATION_STATUS  0x00000800
 
 #define IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO_STR      "idzero"
 #define IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION_STR "forcepermsg"
@@ -288,6 +289,7 @@ struct hostrange_cmd_args
 #define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE_STR      "opensesspriv"
 #define IPMI_TOOL_WORKAROUND_FLAGS_IGNORE_SOL_PAYLOAD_SIZE_STR     "solpayloadsize"
 #define IPMI_TOOL_WORKAROUND_FLAGS_IGNORE_SOL_PORT_STR             "solport"
+#define IPMI_TOOL_WORKAROUND_FLAGS_SKIP_SOL_ACTIVATION_STATUS_STR  "solstatus"
 
 #define IPMI_AUTHENTICATION_TYPE_NONE_STR                               "none"
 #define IPMI_AUTHENTICATION_TYPE_STRAIGHT_PASSWORD_KEY_STR              "straight_password_key"
