@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmiconsole.c,v 1.79 2007/10/18 16:18:46 chu11 Exp $
+ *  $Id: ipmiconsole.c,v 1.86 2008/08/12 18:14:37 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -51,9 +51,9 @@
 #endif /* !TIME_WITH_SYS_TIME */
 #include <sys/types.h>
 #include <sys/select.h>
-#ifdef WITH_PTHREADS
+#ifdef HAVE_PTHREAD_H
 #include <pthread.h>
-#endif /* WITH_PTHREADS */
+#endif /* HAVE_PTHREAD_H */
 #include <sys/resource.h>
 #include <assert.h>
 #include <errno.h>
@@ -61,13 +61,15 @@
 #include "ipmiconsole.h"
 #include "ipmiconsole_defs.h"
 
-#include "secure.h"
 #include "ipmiconsole_ctx.h"
 #include "ipmiconsole_debug.h"
 #include "ipmiconsole_engine.h"
 #include "ipmiconsole_fiid_wrappers.h"
 #include "ipmiconsole_util.h"
 
+#include "freeipmi-portability.h"
+#include "secure.h"
+
 /* 
  * ipmi console errmsgs
  */
@@ -97,14 +99,15 @@ static char *ipmiconsole_errmsgs[] =
     "BMC Busy",			                        /* 21 */
     "BMC Error",		                        /* 22 */
     "BMC Implementation",                               /* 23 */
-    "session timeout",		                        /* 24 */
-    "excess retransmissions sent",                      /* 25 */
-    "excess errors received",                           /* 26 */
-    "out of memory",		                        /* 27 */
-    "too many open files",                              /* 28 */
-    "internal system error",	                        /* 20 */
-    "internal error",		                        /* 30 */
-    "errnum out of range",	                        /* 31 */
+    "connection timeout",		                /* 24 */
+    "session timeout",		                        /* 25 */
+    "excess retransmissions sent",                      /* 26 */
+    "excess errors received",                           /* 27 */
+    "out of memory",		                        /* 28 */
+    "too many open files",                              /* 29 */
+    "internal system error",	                        /* 30 */
+    "internal error",		                        /* 31 */
+    "errnum out of range",	                        /* 32 */
     NULL
   };
 
@@ -199,7 +202,10 @@ ipmiconsole_engine_submit(ipmiconsole_ctx_t c,
     {
       IPMICONSOLE_DEBUG(("pthread_mutex_lock: %s", strerror(perr)));
       ipmiconsole_ctx_set_errnum(c, IPMICONSOLE_ERR_INTERNAL_ERROR);
-      goto cleanup;
+      /* don't go to cleanup, b/c the engine will call
+       * ipmiconsole_ctx_connection_cleanup_session_not_submitted().
+       */
+      goto cleanup_ctx_fds_only;
     }
   
   /* Check for NOT_SUBMITTED, conceivably SOL_ERROR or SOL_ESTABLISHED
@@ -212,15 +218,17 @@ ipmiconsole_engine_submit(ipmiconsole_ctx_t c,
     {
       IPMICONSOLE_DEBUG(("pthread_mutex_unlock: %s", strerror(perr)));
       ipmiconsole_ctx_set_errnum(c, IPMICONSOLE_ERR_INTERNAL_ERROR);
-      goto cleanup;
+      goto cleanup_ctx_fds_only;
     }
 
+  /* may have been set already */
   c->session_submitted++;
   ipmiconsole_ctx_set_errnum(c, IPMICONSOLE_ERR_SUCCESS);
   return 0;
 
  cleanup:
-  ipmiconsole_ctx_connection_cleanup(c);
+  ipmiconsole_ctx_connection_cleanup_session_not_submitted(c);
+ cleanup_ctx_fds_only:
   /* fds are the API responsibility, even though we didn't create them */
   ipmiconsole_ctx_fds_cleanup(c);
   return -1;
@@ -414,7 +422,7 @@ ipmiconsole_engine_submit_block(ipmiconsole_ctx_t c)
   if (_ipmiconsole_block(c) < 0)
     {
       /* don't go to cleanup, b/c the engine will call
-       * _ipmiconsole_ctx_connection_cleanup().
+       * ipmiconsole_ctx_connection_cleanup_session_not_submitted().
        */
       goto cleanup_ctx_fds_only;
     }
@@ -441,14 +449,16 @@ ipmiconsole_engine_submit_block(ipmiconsole_ctx_t c)
 
   _ipmiconsole_blocking_notification_cleanup(c);
 
+  /* may have been set already */
   c->session_submitted++;
   ipmiconsole_ctx_set_errnum(c, IPMICONSOLE_ERR_SUCCESS);
   return 0;
 
  cleanup:
-  ipmiconsole_ctx_connection_cleanup(c);
+  ipmiconsole_ctx_connection_cleanup_session_not_submitted(c);
  cleanup_ctx_fds_only:
   _ipmiconsole_blocking_notification_cleanup(c);
+  /* fds are the API responsibility, even though we didn't create them */
   ipmiconsole_ctx_fds_cleanup(c);
   return -1;
 }
