@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: ipmimonitoring.c,v 1.64.2.5 2009/04/08 21:12:39 chu11 Exp $
+ *  $Id: ipmimonitoring.c,v 1.64.2.6 2009/05/29 00:34:04 chu11 Exp $
  *****************************************************************************
  *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
@@ -185,6 +185,7 @@ _setup_ipmimonitoring_lib (struct ipmimonitoring_arguments *args)
 int
 run_cmd_args (ipmimonitoring_state_data_t *state_data)
 {
+  struct ipmi_monitoring_ipmi_config conf;
   struct ipmimonitoring_arguments *args;
   unsigned int sensor_reading_flags;
   int i, num;
@@ -241,11 +242,52 @@ run_cmd_args (ipmimonitoring_state_data_t *state_data)
   if (args->bridge_sensors)
     sensor_reading_flags |= IPMI_MONITORING_SENSOR_READING_FLAGS_BRIDGE_SENSORS;
   
+  memset (&conf, '\0', sizeof (struct ipmi_monitoring_ipmi_config));
+  memcpy (&conf, &(args->conf), sizeof (struct ipmi_monitoring_ipmi_config));
+  
+  /* 
+   * achu: configure per-situation workaround flags.  Can't be done
+   * below in _convert_to_ipmimonitoring_options() b/c user could have
+   * input localhost/127.0.0.1.
+   */
+  if (state_data->hostname
+      && strcasecmp (state_data->hostname, "localhost")
+      && strcmp (state_data->hostname, "127.0.0.1"))
+    {
+      if (conf.protocol_version == IPMI_MONITORING_PROTOCOL_VERSION_2_0)
+        {
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO;
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION;
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE;
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER;
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES;
+        }
+      else
+        {
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES;
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_INTEL_2_0_SESSION)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_INTEL_2_0_SESSION;
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION;
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_SUN_2_0_SESSION;
+          if (args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE)
+            conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE;
+        }
+    }
+  /* else - no inband workaround flags yet */
+
   if (!args->sensors_length && !args->ipmimonitoring_groups_length)
     {
       if ((num = ipmi_monitoring_sensor_readings_by_record_id(state_data->ctx,
                                                               state_data->hostname,
-                                                              &(args->conf),
+                                                              &conf,
                                                               sensor_reading_flags,
                                                               NULL,
                                                               0)) < 0)
@@ -261,7 +303,7 @@ run_cmd_args (ipmimonitoring_state_data_t *state_data)
     {
       if ((num = ipmi_monitoring_sensor_readings_by_record_id(state_data->ctx,
                                                               state_data->hostname,
-                                                              &(args->conf),
+                                                              &conf,
                                                               sensor_reading_flags,
                                                               args->sensors,
                                                               args->sensors_length)) < 0)
@@ -283,7 +325,7 @@ run_cmd_args (ipmimonitoring_state_data_t *state_data)
     {
       if ((num = ipmi_monitoring_sensor_readings_by_sensor_group(state_data->ctx,
                                                                  state_data->hostname,
-                                                                 &(args->conf),
+                                                                 &conf,
                                                                  sensor_reading_flags,
                                                                  args->ipmimonitoring_groups,
                                                                  args->ipmimonitoring_groups_length)) < 0)
@@ -671,6 +713,8 @@ _grab_ipmimonitoring_options(struct ipmimonitoring_arguments *cmd_args)
         cmd_args->conf.driver_type = IPMI_MONITORING_DRIVER_TYPE_SSIF;
       else if (cmd_args->common.driver_type == IPMI_DEVICE_OPENIPMI)
         cmd_args->conf.driver_type = IPMI_MONITORING_DRIVER_TYPE_OPENIPMI;
+      else if (cmd_args->common.driver_type == IPMI_DEVICE_SUNBMC)
+        cmd_args->conf.driver_type = IPMI_MONITORING_DRIVER_TYPE_SUNBMC;
     }
   else
     {
@@ -714,24 +758,7 @@ _grab_ipmimonitoring_options(struct ipmimonitoring_arguments *cmd_args)
   cmd_args->conf.retransmission_timeout_len = cmd_args->common.retransmission_timeout;
 
   cmd_args->conf.workaround_flags = 0;
-  if (cmd_args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO)
-    cmd_args->conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO;
-  if (cmd_args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION)
-    cmd_args->conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION;
-  if (cmd_args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE)
-    cmd_args->conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE;
-  if (cmd_args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER)
-    cmd_args->conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER;
-  if (cmd_args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES)
-    cmd_args->conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES;
-  if (cmd_args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_INTEL_2_0_SESSION)
-    cmd_args->conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_INTEL_2_0_SESSION;
-  if (cmd_args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION)
-    cmd_args->conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION;
-  if (cmd_args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION)
-    cmd_args->conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_SUN_2_0_SESSION;
-  if (cmd_args->common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE)
-    cmd_args->conf.workaround_flags |= IPMI_MONITORING_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE;
+  /* calculate workaround flags later dependent on settings/inputs */
 
   if (cmd_args->common.debug)
     {
