@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmipower_wrappers.h,v 1.24 2007/10/18 16:18:53 chu11 Exp $
+ *  $Id: ipmipower_wrappers.h,v 1.28 2008/05/19 23:27:51 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2003-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -28,6 +28,7 @@
 #define _IPMIPOWER_WRAPPERS_H
 
 #include "argv.h"
+#include "ierror.h"
 #include "fd.h"
 #include "list.h"
 #include "cbuf.h"
@@ -35,7 +36,6 @@
 #include "secure.h"
 #include "timeval.h"
 #include "wrappers.h"
-#include "error.h"
 #include "conffile.h"
 
 #include <freeipmi/freeipmi.h>
@@ -118,43 +118,4 @@ int32_t Fiid_obj_set_data(fiid_obj_t obj, char *field, uint8_t *data, uint32_t d
  */
 int32_t Fiid_obj_set_all(fiid_obj_t obj, uint8_t *data, uint32_t data_len);
 
-/* Ipmi_dump_lan_packet
- * - Dump lan contents
- */
-void Ipmi_dump_lan_packet(int fd,
-                          char *prefix,
-                          char *hdr,
-                          uint8_t *pkt,
-                          uint32_t pkt_len,
-                          fiid_template_t tmpl_lan_msg_hdr,
-                          fiid_template_t tmpl_cmd);
-
-/* Ipmi_dump_rmcp_packet
- * - Dump rmcp contents
- */
-void Ipmi_dump_rmcp_packet(int fd,
-                           char *prefix,
-                           char *hdr,
-                           uint8_t *pkt,
-                           uint32_t pkt_len,
-                           fiid_template_t tmpl_cmd);
-
-/* Ipmi_dump_rmcpplus_packet
- * - Dump rmcp contents
- */
-void Ipmi_dump_rmcpplus_packet (int fd,
-                                char *prefix,
-                                char *hdr,
-                                uint8_t authentication_algorithm,
-                                uint8_t integrity_algorithm,
-                                uint8_t confidentiality_algorithm,
-                                uint8_t *integrity_key,
-                                uint32_t integrity_key_len,
-                                uint8_t *confidentiality_key,
-                                uint32_t confidentiality_key_len,
-                                uint8_t *pkt,
-                                uint32_t pkt_len,
-                                fiid_template_t tmpl_lan_msg_hdr,
-                                fiid_template_t tmpl_cmd);
-
 #endif /* _IPMIPOWER_WRAPPERS_H */
