@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: ipmi-sdr-cache-create.c,v 1.18 2008/08/12 18:14:45 chu11 Exp $
+ *  $Id: ipmi-sdr-cache-create.c,v 1.18.4.1 2009/08/13 23:01:49 chu11 Exp $
  *****************************************************************************
  *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
@@ -626,8 +626,53 @@ ipmi_sdr_cache_create(ipmi_sdr_cache_ctx_t ctx,
 
   if (record_count_written != ctx->record_count)
     {
-      SDR_CACHE_ERRNUM_SET(IPMI_SDR_CACHE_CTX_ERR_CACHE_CREATE_INVALID_RECORD_COUNT);
-      goto cleanup;
+      /*
+       * IPMI Workaround (achu)
+       *
+       * Discovered on Fujitsu RX 100
+       *
+       * The record_count listed from the Get SDR Repository Info command
+       * is not consistent with the length of SDR records stored.
+       *
+       * We will assume that if we reached the end of the SDR record list
+       * (i.e. next_record_id == 0xFFFF), a non-zero number of records
+       * were written, and it is less than the record_count given, it's ok
+       * and we can continue on.
+       */
+      if (next_record_id == IPMI_SDR_RECORD_ID_LAST
+          && record_count_written
+          && record_count_written < ctx->record_count)
+        {
+          unsigned int total_bytes_written_temp = 0;
+          
+          ctx->record_count = record_count_written;
+          
+          /* need to seek back to the beginning of the file and
+           * re-write the header info with the correct number of
+           * records
+           */
+          
+          if (lseek (fd, 0, SEEK_SET) < 0)
+            {
+              SDR_CACHE_ERRNUM_SET(IPMI_SDR_CACHE_CTX_ERR_SYSTEM_ERROR);
+              goto cleanup;
+            }
+          
+          if (_sdr_cache_header_write (ctx,
+                                       ipmi_ctx,
+                                       fd,
+                                       &total_bytes_written_temp,
+                                       ctx->sdr_version,
+                                       ctx->record_count,
+                                       ctx->most_recent_addition_timestamp,
+                                       ctx->most_recent_erase_timestamp) < 0)
+            goto cleanup;
+        }
+      else
+        {
+          SDR_CACHE_ERRNUM_SET(IPMI_SDR_CACHE_CTX_ERR_CACHE_CREATE_INVALID_RECORD_COUNT);
+          goto cleanup;
+        }
     }
   
   rv = 0;
