@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: rmcpping.c,v 1.24 2007/10/18 16:18:54 chu11 Exp $
+ *  $Id: rmcpping.c,v 1.37 2008/08/12 18:14:45 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2003-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -26,7 +26,7 @@
 
 #if HAVE_CONFIG_H
 #include "config.h"
-#endif
+#endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -41,7 +41,9 @@
 
 #include <freeipmi/freeipmi.h>
 
-#include "ipmi-ping.h"
+#include "freeipmi-portability.h"
+#include "debug-util.h"
+#include "ping-tool-common.h"
 
 #define _supported(x)   (x) ? "supported" : "not-supported"
 
@@ -49,7 +51,7 @@ static fiid_obj_t
 _fiid_obj_create(fiid_template_t tmpl)
 {
   fiid_obj_t obj;
- 
+
   assert(tmpl != NULL);
  
   if ((obj = fiid_obj_create(tmpl)) == NULL)
@@ -64,11 +66,13 @@ _fiid_obj_get(fiid_obj_t obj, char *field, uint64_t *val)
   assert(obj && field && val);
 
   if (fiid_obj_get(obj, field, val) < 0)
-    ipmi_ping_err_exit("fiid_obj_get: %s", strerror(errno));
+    ipmi_ping_err_exit("fiid_obj_get: %s",
+                       fiid_strerror(fiid_obj_errnum(obj)));
 }
 
 int 
-createpacket(char *buffer, 
+createpacket(char *destination,
+             char *buffer, 
              int buflen, 
              unsigned int sequence_number, 
              int version,
@@ -78,6 +82,7 @@ createpacket(char *buffer,
   fiid_obj_t obj_rmcp_cmd = NULL;
   int len;
 
+  assert(destination != NULL);
   assert(buffer != NULL);
     
   if (buflen < 0)
@@ -107,8 +112,17 @@ createpacket(char *buffer,
   
   if (debug)
     {
+      char hdrbuf[DEBUG_UTIL_HDR_BUFLEN];
+      
+      debug_hdr_str(DEBUG_UTIL_TYPE_NONE,
+                    DEBUG_UTIL_DIRECTION_NONE,
+                    DEBUG_UTIL_RMCPPING_STR,
+                    hdrbuf,
+                    DEBUG_UTIL_HDR_BUFLEN);
+
       if (ipmi_dump_rmcp_packet(STDERR_FILENO, 
-                                "Ping", 
+                                destination,
+                                hdrbuf, 
                                 NULL, 
                                 (uint8_t *)buffer, 
                                 (uint32_t)len, 
@@ -122,7 +136,8 @@ createpacket(char *buffer,
 }
 
 int 
-parsepacket(char *buffer, 
+parsepacket(char * destination,
+            char *buffer, 
             int buflen, 
             const char *from, 
             unsigned int sequence_number, 
@@ -135,6 +150,7 @@ parsepacket(char *buffer,
   uint64_t message_type, ipmi_supported, message_tag;
   int retval = -1;
 
+  assert(destination != NULL);
   assert(buffer != NULL && from != NULL);
   
   if (buflen == 0)
@@ -145,8 +161,17 @@ parsepacket(char *buffer,
 
   if (debug)
     {
+      char hdrbuf[DEBUG_UTIL_HDR_BUFLEN];
+      
+      debug_hdr_str(DEBUG_UTIL_TYPE_NONE,
+                    DEBUG_UTIL_DIRECTION_NONE,
+                    DEBUG_UTIL_RMCPPONG_STR,
+                    hdrbuf,
+                    DEBUG_UTIL_HDR_BUFLEN);
+
       if (ipmi_dump_rmcp_packet(STDERR_FILENO, 
-                                "Pong", 
+                                destination,
+                                hdrbuf,
                                 NULL,
                                 (uint8_t *)buffer,
                                 (uint32_t)buflen, 
@@ -154,7 +179,10 @@ parsepacket(char *buffer,
         ipmi_ping_err_exit("ipmi_dump_rmcp_packet: %s", strerror(errno));
     }
 
-  if (unassemble_rmcp_pkt(buffer, buflen, obj_rmcp_hdr, obj_rmcp_cmd) < 0)
+  if (unassemble_rmcp_pkt((uint8_t *)buffer, 
+                          buflen, 
+                          obj_rmcp_hdr,
+                          obj_rmcp_cmd) < 0)
     ipmi_ping_err_exit("unassemble_rmcp_pkt: %s", strerror(errno));
 
   _fiid_obj_get(obj_rmcp_cmd, "message_type", (uint64_t *)&message_type);
